@@ -5,7 +5,7 @@ Images utility library
 @author: avigan
 '''
 
-import collections
+import collections.abc
 import numpy as np
 import scipy.fftpack as fft
 import scipy.ndimage as ndimage
@@ -147,7 +147,7 @@ def shift(array, shift_value, method='fft', mode='constant', cval=0):
         raise ValueError('This function can shift only 1D or 2D arrays')
 
     # check that shift value is fine
-    if isinstance(shift_value, collections.Iterable):
+    if isinstance(shift_value, collections.abc.Iterable):
         shift_value = np.array(shift_value).ravel()
         if (shift_value.size != Ndim):
             raise ValueError('Number of dimensions in array and shift don\'t match')
@@ -161,7 +161,7 @@ def shift(array, shift_value, method='fft', mode='constant', cval=0):
         method = 'roll'
     else:
         # force integer values
-        if method is 'roll':
+        if method == 'roll':
             shift_value = np.round(shift_value)
         
     # FFT limitations
@@ -722,7 +722,7 @@ def scale(array, scale_value, center=None, new_dim=None, method='fft', mode='con
                           'The center of rotation is exactly at ((dimx-1)/2, dimy/2).')
     
     # check that scale value is fine
-    if isinstance(scale_value, collections.Iterable):
+    if isinstance(scale_value, collections.abc.Iterable):
         scale_value = np.array(scale_value).ravel()
         if (scale_value.size != Ndim):
             raise ValueError('Number of dimensions in array and scale value don\'t match')
@@ -838,11 +838,11 @@ def sigma_filter(img, box=5, nsigma=3, iterate=False, return_mask=False, max_ite
     box2 = box**2
 
     kernel = Box2DKernel(box)
-    img_clip = (convolve(img, kernel)*box2 - img) / (box2-1)
+    img_clip = (convolve(img, kernel, fill_value=0, nan_treatment='fill', preserve_nan=True)*box2 - img) / (box2-1)
 
     imdev = (img - img_clip)**2
     fact = nsigma**2 / (box2-2)
-    imvar = fact*(convolve(imdev, kernel)*box2 - imdev)
+    imvar = fact*(convolve(imdev, kernel, fill_value=0, nan_treatment='fill', preserve_nan=True)*box2 - imdev)
 
     # following solution is faster but does not support bad pixels
     # see avigan/SPHERE#49
