@@ -125,34 +125,34 @@ class ReductionPath(object):
 
         # tmp
         if self._tmp.exists():
-            logger.debug('> remove {}'.format(self._tmp))
+            logger.debug(f'> remove {self._tmp}')
             shutil.rmtree(self._tmp, ignore_errors=True)
 
         # sof
         if self._sof.exists():
-            logger.debug('> remove {}'.format(self._sof))
+            logger.debug(f'> remove {self._sof}')
             shutil.rmtree(self._sof, ignore_errors=True)
 
         # calib
         if self._calib.exists():
-            logger.debug('> remove {}'.format(self._calib))
+            logger.debug(f'> remove {self._calib}')
             shutil.rmtree(self._calib, ignore_errors=True)
 
         # preproc
         if self._preproc.exists():
-            logger.debug('> remove {}'.format(self._preproc))
+            logger.debug(f'> remove {self._preproc}')
             shutil.rmtree(self._preproc, ignore_errors=True)
 
         # raw
         if delete_raw:
             if self._raw.exists():
-                logger.debug('> remove {}'.format(self._raw))
+                logger.debug(f'> remove {self._raw}')
                 logger.warning('   ==> delete raw files')
                 shutil.rmtree(self._raw, ignore_errors=True)
 
         # products
         if delete_products:
             if self._products.exists():
-                logger.debug('> remove {}'.format(self._products))
+                logger.debug(f'> remove {self._products}')
                 logger.warning('   ==> delete products')
                 shutil.rmtree(self._products, ignore_errors=True)
